------------------------------------------------------------------------------
-- MakeMeGetMyMain - Alarms you when something happens to your character
------------------------------------------------------------------------------
-- Trigger_Loot.lua - Triggered if character loots special items
--
-- Author: Expelliarm5s / July 2020 / All Rights Reserved
--
-- Version 1.1.5
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI

local addonName, addon = ...
local modle = addon:NewModule("Loot", "AceEvent-3.0", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
-- local private = {}
------------------------------------------------------------------------------

function modle:ModuleName()
	return modle.moduleName
end

function modle:Login()
end

function modle:ModuleIcon()
	return "INTERFACE\\ICONS\\INV_Misc_Gift_01"
end

function modle:TriggerName()
	return L["Character got special item!"]
end

function modle:TriggerDesc()
	return L["Alarm fires on special item drop."]
end

function modle:Login()
	modle:RegisterEvent("LOOT_OPENED")
end

function modle:GetItemID(val)
	if type(val) == "number" then
		return val
	end

	if type(val) == "string" then
		local id = val:match("item:([0-9]+)")
		if id and tonumber(id) then
			return tonumber(id)
		end
	end
end

function modle:GetOptions()
	local options = {
		type = "input",
		name = L["List of ItemIDs:"],
		desc = L["ItemIDs to trigger an alarm on drop, e.g. for BfA mounts: \"163573, 163574, 163575, 163576, 163131\"."],
		width = "full",
		get = function(info)
			return addon.db.global.LootItemIDs
		end,
		set = function(info, value)
			if value then
				addon.db.global.LootItemIDs = value
			end
		end,
	}
	return options
end

function modle:LOOT_OPENED(event)
	addon:DebugPrintf(modle.moduleName .. "~  %s", tostring(event))
	if event == "LOOT_OPENED" then
		if addon.isEnabled and addon.db.global[modle.moduleName] then
			for i = 1, GetNumLootItems() do
				local slotType = GetLootSlotType(i);
				if slotType == 1 then
					-- items
					local itemLink = GetLootSlotLink(i)
					local itemID = modle:GetItemID(itemLink)
					addon:DebugPrintf(modle.moduleName .. "~%s: itemLink = %s itemID = %s", tostring(i), tostring(itemLink), tostring(itemID))
					if itemID and addon.db.global.LootItemIDs and type(addon.db.global.LootItemIDs) == "string" then
						local itemIDs = addon.db.global.LootItemIDs .. ","
						local found = false
						itemIDs:gsub("([0-9]+),",
							function(j)
								j = gsub(j, "^ ", "")
								j = gsub(j, " $", "")
								-- addon:DebugPrintf(modle.moduleName .. "~j = %s", tostring(j))
								if j and tonumber(j) then
									if tonumber(itemID) == tonumber(j) then
										addon:DebugPrintf(modle.moduleName .. "~  found %s for ItemID %s", tostring(itemLink), tostring(itemID))
										found = true
									end
								end
							end)
						if found then
							addon:DebugPrintf(modle.moduleName .. "~  -> GUI:Fire(%s)", modle.moduleName)
							addon:Printf(format(L["Module %s: %s (%s / %s)"], modle.moduleName, modle:TriggerName(), tostring(itemID), tostring(itemLink)))
							if addon.GUI.Fire then
								addon.GUI:Fire(modle.moduleName)
							end
							-- only first itemID
							return
						end
					end
				end
			end
		end
	end
end

-- EOF